@@ -1,10 +1,5 @@
 <?php
 /**
- * @ingroup Media
- * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
- * @copyright Copyright © 2005, Ævar Arnfjörð Bjarmason
- * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -20,7 +15,12 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  * http://www.gnu.org/copyleft/gpl.html
  *
+ * @ingroup Media
+ * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>
+ * @copyright Copyright © 2005, Ævar Arnfjörð Bjarmason
+ * @license http://www.gnu.org/copyleft/gpl.html GNU General Public License
  * @see http://exif.org/Exif2-2.PDF The Exif 2.2 specification
+ * @file
  */
 
 /**
@@ -28,23 +28,21 @@
  * @ingroup Media
  */
 class Exif {
+
+	const BYTE      = 1;    //!< An 8-bit (1-byte) unsigned integer.
+	const ASCII     = 2;    //!< An 8-bit byte containing one 7-bit ASCII code. The final byte is terminated with NULL.
+	const SHORT     = 3;    //!< A 16-bit (2-byte) unsigned integer.
+	const LONG      = 4;    //!< A 32-bit (4-byte) unsigned integer.
+	const RATIONAL  = 5;    //!< Two LONGs. The first LONG is the numerator and the second LONG expresses the denominator
+	const UNDEFINED = 7;    //!< An 8-bit byte that can take any value depending on the field definition
+	const SLONG     = 9;    //!< A 32-bit (4-byte) signed integer (2's complement notation),
+	const SRATIONAL = 10;   //!< Two SLONGs. The first SLONG is the numerator and the second SLONG is the denominator.
+
 	//@{
 	/* @var array
 	 * @private
 	 */
 
-	/**#@+
-	 * Exif tag type definition
-	 */
-	const BYTE      = 1;    # An 8-bit (1-byte) unsigned integer.
-	const ASCII     = 2;    # An 8-bit byte containing one 7-bit ASCII code. The final byte is terminated with NULL.
-	const SHORT     = 3;    # A 16-bit (2-byte) unsigned integer.
-	const LONG      = 4;    # A 32-bit (4-byte) unsigned integer.
-	const RATIONAL  = 5;    # Two LONGs. The first LONG is the numerator and the second LONG expresses the denominator
-	const UNDEFINED = 7;    # An 8-bit byte that can take any value depending on the field definition
-	const SLONG     = 9;    # A 32-bit (4-byte) signed integer (2's complement notation),
-	const SRATIONAL = 10;   # Two SLONGs. The first SLONG is the numerator and the second SLONG is the denominator.
-
 	/**
 	 * Exif tags grouped by category, the tagname itself is the key and the type
 	 * is the value, in the case of more than one possible value type they are
