@@ -1,5 +1,8 @@
 <?php
 /** Ewe (Eʋegbe)
+ *
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
  *
  * @ingroup Language
  * @file
@@ -28,7 +31,7 @@ $messages = array(
 'thursday'      => 'Yawoɖagbe',
 'friday'        => 'Fiɖagbe',
 'saturday'      => 'Memleɖagbe',
-'sun'           => 'Dzo',
+'sun'           => 'Kɔs',
 'mon'           => 'Dzo',
 'tue'           => 'Brã',
 'wed'           => 'Kuɖ',
@@ -75,11 +78,13 @@ $messages = array(
 'about'          => 'Ŋutinya',
 'newwindow'      => '(eʋua fesre yeye)',
 'cancel'         => 'Dzudzɔ etɔtrɔ',
+'qbfind'         => 'Di',
 'qbedit'         => 'Trɔ asi le eŋu',
 'qbpageoptions'  => 'Axa sia',
 'qbmyoptions'    => 'Nyeƒe axawo',
 'qbspecialpages' => 'Axa tɔxewo',
 'mypage'         => 'Axa nye',
+'mytalk'         => 'Nyeƒe nyamedzroƒe',
 'navigation'     => 'Mɔtabiala',
 'and'            => '&#32;kpakple',
 
@@ -94,22 +99,30 @@ $messages = array(
 'history'          => 'Axa sia ƒe tata xoxoawo',
 'history_short'    => 'Xoxoawo',
 'edit'             => 'Trɔ asi le eŋu',
+'create'           => 'Dze egɔme',
 'editthispage'     => 'Ðɔ axa sia ɖo',
+'create-this-page' => 'Dze axa sia gɔme',
 'delete'           => 'Tutui',
+'deletethispage'   => 'Tutu axa sia',
+'protect'          => 'Dzɔ eŋu',
+'protect_change'   => 'ɖɔlii',
+'protectthispage'  => 'Dzɔ axa sia ŋu',
 'newpage'          => 'Axa yeye',
 'talkpagelinktext' => 'Nyamedzroƒe',
 'specialpage'      => 'Axa Tɔxe',
 'personaltools'    => 'Wòƒe dɔwɔnuwo',
-'postcomment'      => 'Ŋlɔ wò susu ɖe afisia',
+'postcomment'      => 'Akpa yeye',
 'talk'             => 'Nyamedzroƒe',
 'toolbox'          => 'Dɔwɔnuɖaka',
 'otherlanguages'   => 'Le gbe bubuwo me',
+'redirectedfrom'   => '(Woɖo wò ɖe afii tso $1)',
+'lastmodifiedat'   => 'Wó ɖɔ axa sia ɖo susue le $2 le ŋkeke $1 dzi.', # $1 date, $2 time
 'jumpto'           => 'Dzo yi:',
 'jumptonavigation' => 'kuɖɔɖoɖo',
 'jumptosearch'     => 'dii',
 
 # All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
-'aboutsite'         => 'Nusi {{SITENAME}} nye',
+'aboutsite'         => '{{SITENAME}} ŋutinya',
 'aboutpage'         => 'Project:Ŋutinya',
 'copyright'         => 'Nusiwo le afii le $1 mɔɖeɖea te.',
 'copyrightpagename' => '{{SITENAME}} mɔɖeɖewo',
@@ -130,23 +143,33 @@ $messages = array(
 'youhavenewmessagesmulti' => 'Du yeyewo le asiwo le $1',
 'editsection'             => 'trɔ asi le eŋu',
 'editold'                 => 'trɔ asi le eŋu',
+'viewsourceold'           => 'kpɔ alesi wó ŋlɔe',
+'editlink'                => 'trɔ asi le eŋu',
+'viewsourcelink'          => 'kpɔ alesi woŋlɔe',
+'editsectionhint'         => 'Trɔ akpa: $1',
+'toc'                     => 'Emenyawo',
 'showtoc'                 => 'fia',
 'hidetoc'                 => 'ɣla',
+'thisisdeleted'           => 'Kpɔ $1 alo wòa gbugbɔe ve hã?',
+'viewdeleted'             => 'Wòa kpɔ $1 a?',
+'red-link-title'          => '$1 (womeŋlɔ axa sia haɖeke o)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => 'Axa',
 'nstab-user'      => 'Ezãla axa',
-'nstab-special'   => 'Tɔxe',
+'nstab-special'   => 'Axa tɔxe',
 'nstab-image'     => 'Agbalẽ',
 'nstab-mediawiki' => 'Du',
 
 # General errors
-'error'         => 'Vodada',
-'badtitle'      => 'Tanya gbegblẽ',
-'viewsource'    => 'Kpɔ alesi wowɔe',
-'viewsourcefor' => '$1 tɔwo',
+'error'           => 'Vodada',
+'badarticleerror' => 'Wòmateŋu awɔ nusia le axa sia dzi o.',
+'badtitle'        => 'Tanya gbegblẽ',
+'viewsource'      => 'Kpɔ alesi wowɔe',
+'viewsourcefor'   => '$1 tɔwo',
 
 # Login and logout pages
+'logouttitle'                => 'Do le eme',
 'login'                      => 'Ge ɖe eme',
 'nav-login-createaccount'    => 'Geɖe me / Ŋlɔ ŋkɔ',
 'userlogin'                  => 'Ge ɖe eme / ŋlɔ ŋkɔ daɖi',
@@ -158,26 +181,37 @@ $messages = array(
 'gotaccount'                 => 'Wò ŋlɔ ŋkɔ xoxoa? $1.',
 'gotaccountlink'             => 'Ge ɖe eme',
 'yourlanguage'               => 'Gbe:',
+'yournick'                   => 'Dzesi',
+'gender-male'                => 'Ŋutsu',
+'gender-female'              => 'Nyɔnu',
 'loginsuccesstitle'          => 'Wò ge ɖe eme azɔ̃.',
 'loginsuccess'               => "'''Wò le {{SITENAME}} me fifia abe \"\$1\" ene.'''",
-'acct_creation_throttle_hit' => 'Taflatse, wòŋlɔ {{PLURAL:$1|1 ŋkɔ|$1 ŋkɔwo}} xoxo.
-Wòmageteŋu agbugbɔ aŋlɔe o.',
+'nouserspecified'            => 'Elebe na ŋlɔ ŋkɔ si wò zãna',
+'acct_creation_throttle_hit' => "Wiki sia zãla aɖe tso wò ''IP address'' ŋlɔ {{PLURAL:$1|1 ŋkɔ|$1 ŋkɔwo}} le ŋkeke si vayi me xoxo. Mɔɖeɖe le na ŋkɔ  ɖeka ko ŋɔŋlɔ le ŋkeke ɖeka me.<br/>
+Le esiata la, ''IP address'' sia zãlawo mekpɔ mɔ aŋlɔ ŋkɔ bubuwo fifia o.",
 'loginlanguagelabel'         => 'Gbe: $1',
 
 # Edit page toolbar
 'sig_tip' => 'Dzesiwò kple gaƒoƒoa',
 
 # Edit pages
-'minoredit'        => 'Esia nye tɔtrɔ sue aɖe ko',
-'watchthis'        => 'Le ŋku ɖe axa sia ŋu',
-'savearticle'      => 'Dzra axa sia ɖo',
-'showpreview'      => 'Fiae do ŋgɔ',
-'showdiff'         => 'Fia tɔtrɔwo',
-'newarticle'       => '(Yeye)',
-'newarticletext'   => "Eva ɖo axa si gɔme womedze haɖeke o. Ne wòadi be yeadze egɔme la, dze nuŋlɔm ɖe go sia me le afi sia ɖome (kpɔ [[{{MediaWiki:Helppage}}|kpekpeɖeŋu nyawo]] na kpekpeɖeŋu bubuwo). Ne wòme ɖoe be yeava afii hafi o la, ekema tia '''megbe''' eye wòa gbugbɔ ayi afisi wòtso va.",
-'previewnote'      => "'''Wole afii fiam do ŋgɔ, wome dzrae ɖo haɖeke o!'''",
-'editing'          => '$1 na etɔtrɔ',
-'copyrightwarning' => "Taflatse, mítsɔe be nusiwo katã netsɔ kpe ɖe {{SITENAME}} ŋu lii fãa le $2 la nu (kpɔ $1 me nyawo). Ne madze ŋuwò be amebubuwo natrɔ asi le nusiwo newɔ ŋuti o, eye woagbugbɔ dɔsiwo newɔ ama na amebubuwo fãa o la, mega dae ɖe afisia o.<br /> Wòle ŋugbe dom na mí bena wò ŋutɔe ŋlɔ nusiawo, alo etsɔe tso afisi mɔɖeɖe li fãa be amesiame na tsɔ nuwo tso afima fãa. '''MEGA DA NUSIWO ŊU MƆƉEƉE MELI NA O ƉE AFISIA O!'''",
+'subject'             => 'Ta nya:',
+'minoredit'           => 'Esia nye tɔtrɔ sue aɖe ko',
+'watchthis'           => 'Le ŋku ɖe axa sia ŋu',
+'savearticle'         => 'Dzra axa sia ɖo',
+'preview'             => 'Kpɔe do ŋgɔ',
+'showpreview'         => 'Fiae do ŋgɔ',
+'showdiff'            => 'Fia tɔtrɔwo',
+'newarticle'          => '(Yeye)',
+'newarticletext'      => "Eva ɖo axa si gɔme womedze haɖeke o. Ne wòadi be yeadze egɔme la, dze nuŋlɔm ɖe go sia me le afi sia ɖome (kpɔ [[{{MediaWiki:Helppage}}|kpekpeɖeŋu nyawo]] na kpekpeɖeŋu bubuwo). Ne wòme ɖoe be yeava afii hafi o la, ekema tia '''megbe''' eye wòa gbugbɔ ayi afisi wòtso va.",
+'previewnote'         => "'''Ɖo ŋku edzi be wole afii fiam do ŋgɔ, wome dzrae ɖo haɖeke o!'''",
+'editing'             => '$1 na etɔtrɔ',
+'editingsection'      => 'Wòle $1 (ƒe akpa aɖe) trɔm',
+'yourtext'            => 'Wò nuŋɔŋlɔ',
+'yourdiff'            => 'Vovototowo',
+'copyrightwarning'    => "Taflatse, mítsɔe be nusiwo katã netsɔ kpe ɖe {{SITENAME}} ŋu lii fãa le $2 la nu (kpɔ $1 me nyawo). Ne madze ŋuwò be amebubuwo natrɔ asi le nusiwo newɔ ŋuti o, eye woagbugbɔ dɔsiwo newɔ ama na amebubuwo fãa o la, mega dae ɖe afisia o.<br /> Wòle ŋugbe dom na mí bena wò ŋutɔe ŋlɔ nusiawo, alo etsɔe tso afisi mɔɖeɖe li fãa be amesiame na tsɔ nuwo tso afima fãa. '''Mega da nusiwo ŋu mɔɖeɖe meli na o la ɖe afisia o!'''",
+'edit-already-exists' => 'Wòmateŋu adze axa sia gɔme o.<br/>
+Wo ŋlɔe xoxo.',
 
 # History pages
 'revisionasof'        => 'Tataa le $1',
@@ -198,21 +232,43 @@ Wòmageteŋu agbugbɔ aŋlɔe o.',
 Dewomahĩ, wotutui le wiki sia dzi alo wotrɔ eƒe ŋkɔ.
 Zã [[Special:Search|nuwo didi le wiki sia dzi]] kpɔ na axa yeyeawo.',
 
+# Revision deletion
+'rev-delundel' => 'fia/ɣla',
+
 # Diffs
 'history-title' => '"$1" ƒe tata xoxoawo',
 'difference'    => '(Vovototowo le tata xoxoawo me)',
 'lineno'        => 'Fli $1:',
 
 # Search results
+'searchresults'         => 'Nusiwo wòdi',
+'searchresults-title'   => 'Nusiwo wofɔ le "$1" didi me',
+'searchsubtitleinvalid' => "Wòdi '''$1'''",
 'noexactmatch'          => "'''Tanya \"\$1\" mesɔ kple axa aɖeke tɔ o.'''
 Wòateŋu [[:\$1|adze axa sia gɔme]].",
 'noexactmatch-nocreate' => "'''Tanya \"\$1\" mesɔ kple axa aɖeke tɔ o.'''",
+'notitlematches'        => 'Mesɔ axa aɖeke ƒe tanya o',
 'prevn'                 => '$1 do ŋgɔ',
+'nextn'                 => '$1 yometɔwo',
 'viewprevnext'          => 'Kpɔ ($1) ($2) ($3)',
-'powersearch'           => 'Dii',
+'searchmenu-exists'     => "'''Axa si ŋkɔ enye \"[[:\$1]]\" le wiki sia dzi'''",
+'searchmenu-new'        => "'''Dze axa \"[[:\$1]]\" sia ŋlɔm ɖe wiki la dzi!'''",
+'search-result-size'    => '$1 ({{PLURAL:$2|nya 1|nya $2}})',
+'showingresultstotal'   => "Wofia {{PLURAL:$4|wò didi '''$1''' tso '''$3''' me|wò didiwo  '''$1 - $2''' tso '''$3''' me}} le afii",
+'powersearch'           => 'Dii de eme',
+'powersearch-field'     => 'Di',
 
 # Preferences page
-'mypreferences' => 'Nyeƒe didiwo',
+'preferences'           => 'Didiwo',
+'mypreferences'         => 'Nyeƒe didiwo',
+'skin-preview'          => 'Kpɔe do ŋgɔ',
+'timezoneregion-africa' => 'Afrika',
+
+# Groups
+'group-sysop' => 'Dɔdzikpɔlawo',
+
+# Associated actions - in the sentence "You do not have permission to X"
+'action-edit' => 'trɔ asi le axa sia ŋu',
 
 # Recent changes
 'recentchanges'        => 'Tɔtrɔ yeyewo',
@@ -221,6 +277,7 @@ Wòateŋu [[:\$1|adze axa sia gɔme]].",
 'rcnotefrom'           => 'Tɔtrɔwo siwo wowɔ tso <b>$2</b> (wofia vaseɖe <b>$1</b>) le afii.',
 'rclistfrom'           => 'Fia tɔtrɔ yeyewo tso $1',
 'rcshowhideminor'      => '$1 tɔtrɔ suewo',
+'rcshowhidebots'       => '$1 bɔtwo',
 'rcshowhideliu'        => '$1 ezãla siwo ŋlɔ ŋkɔ',
 'rcshowhideanons'      => '$1 ŋkɔ maŋlɔlawo',
 'rcshowhidemine'       => '$1 nyeƒe tɔtrɔwo',
@@ -245,17 +302,21 @@ Wòateŋu [[:\$1|adze axa sia gɔme]].",
 'filehist-datetime' => 'Ŋkeke/Gaƒoƒo',
 'filehist-user'     => 'Ezãla',
 'linkstoimage'      => 'Axa {{PLURAL:$1|sia|$1 siawo}} ku ɖe agbalẽ sia ŋu.',
+'sharedupload'      => "Agbalɛ̃ sia tso $1 eye dɔ (''alo project'') bubuawo woateŋu azãe fãa.", # $1 is the repo name, $2 is shareduploadwiki(-desc)
 
 # MIME search
 'mimesearch' => 'MIME me didi',
 
 # Random page
 'randompage'         => 'Axaa ɖe ko',
-'randompage-nopages' => 'Axa aɖeke mele akpa sia o.',
+'randompage-nopages' => 'Axa aɖeke mele "$1" o.',
 
 # Statistics
 'statistics' => 'Akɔntawo',
 
+'brokenredirects-edit'   => '(trɔ asi le eŋu)',
+'brokenredirects-delete' => '(tutui)',
+
 'fewestrevisions' => 'Axawo siwo womeɖɔɖo zã o',
 
 # Miscellaneous special pages
@@ -269,6 +330,13 @@ Wòateŋu [[:\$1|adze axa sia gɔme]].",
 'ancientpages'   => 'Axawo si wo do xoxo wu',
 'move'           => 'Ɖɔli eƒe nɔƒe',
 'movethispage'   => 'Ɖɔli axa sia ƒe nɔƒe',
+'pager-newer-n'  => '{{PLURAL:$1|1 yeyea|$1 yeyeawo}}',
+'pager-older-n'  => '{{PLURAL:$1|1 xoxoa|$1 xoxoawo}}',
+
+# Book sources
+'booksources'               => 'Agbalɛ̃wo ƒe tsoƒe',
+'booksources-search-legend' => 'Di agbalẽwo ƒe tsoƒewo',
+'booksources-go'            => 'Yi',
 
 # Special:Log
 'specialloguserlabel'  => 'Ezãla:',
@@ -280,6 +348,7 @@ Wòateŋu [[:\$1|adze axa sia gɔme]].",
 'nextpage'       => 'Axa yometɔ ($1)',
 'prevpage'       => 'Axa do ŋgɔ ($1)',
 'allpagesfrom'   => 'Fia axawo tso:',
+'allpagesto'     => 'Fia axawo vaseɖe:',
 'allarticles'    => 'Axawo katã',
 'allinnamespace' => 'Axawo katã ($1 namespace)',
 'allpagessubmit' => 'Yi',
@@ -288,8 +357,9 @@ Wòateŋu [[:\$1|adze axa sia gɔme]].",
 'linksearch-ok' => 'Dii',
 
 # Special:Log/newusers
+'newuserlogpage'           => 'Ŋkɔŋlɔla yeyewo ƒe xexlẽme',
 'newuserlog-create-entry'  => 'Nuŋlɔla yeye',
-'newuserlog-create2-entry' => 'woŋlɔ ŋkɔ na $1',
+'newuserlog-create2-entry' => 'woŋlɔ ŋkɔ yeye na $1',
 
 # Watchlist
 'watchlistfor'  => "(na '''$1''')",
@@ -299,12 +369,14 @@ Wòateŋu [[:\$1|adze axa sia gɔme]].",
 
 # Delete
 'deletepage'     => 'Tutu axa sia',
+'actioncomplete' => 'Wowɔe vɔ',
 'deletedarticle' => 'wotutu "[[$1]]"',
 
 # Protect
 'prot_1movedto2'              => '[[$1]] wohee yi [[$2]]',
-'protect-level-autoconfirmed' => 'Xemɔ na ŋkɔmaŋlɔlawo',
-'protect-expiry-options'      => 'gaƒoƒo 2:2 hours,ŋkeke 1:1 day,ŋkeke 3:3 days,kɔsiɖa 1:1 week,kɔsiɖa 2:2 weeks,ɣleti 1:1 month,ɣleti 3:3 months,ɣleti 6:6 months,ƒe 1:1 year,tegbe:infinite', # display1:time1,display2:time2,...
+'protect-default'             => 'Namɔ ezãlawo katã',
+'protect-level-autoconfirmed' => 'Xemɔ na ame yeyewo kple ŋkɔmaŋlɔlawo',
+'protect-expiry-options'      => 'gaƒoƒo 1:1 hour,ŋkeke 1:1 day,kɔsiɖa 1:1 week,kɔsiɖa 2:2 weeks,ɣleti 1:1 month,ɣleti 3:3 months,ɣleti 6:6 months,ƒe 1:1 year,tegbe:infinite', # display1:time1,display2:time2,...
 'restriction-type'            => 'Mɔɖeɖe:',
 
 # Undelete
@@ -315,29 +387,35 @@ Wòateŋu [[:\$1|adze axa sia gɔme]].",
 'invert' => 'Trɔ tatiawo tu',
 
 # Contributions
-'contributions' => 'Ezãla ƒe nuŋɔŋlɔwo',
-'mycontris'     => 'Nyeƒe nuŋɔŋlɔwo',
-'uctop'         => '(tametɔ)',
-'month'         => 'Tso ɣleti (kple do ŋgɔ):',
-'year'          => 'Tso ƒe (kple do ŋgɔ):',
+'contributions'       => 'Ezãla ƒe nuŋɔŋlɔwo',
+'contributions-title' => '$1 ƒe nuŋɔŋlɔwo',
+'mycontris'           => 'Nyeƒe nuŋɔŋlɔwo',
+'contribsub2'         => 'Na $1 ($2)',
+'uctop'               => '(tametɔ)',
+'month'               => 'Tso ɣleti (kple do ŋgɔ):',
+'year'                => 'Tso ƒe (kple do ŋgɔ):',
 
 'sp-contributions-newbies' => 'Fia ŋkɔŋlɔla yeyewo ƒe ɖɔɖɔɖowo ko.',
 
 # What links here
 'whatlinkshere'       => 'Nusiwo kaa afii ŋu',
 'whatlinkshere-title' => 'Axawo siwo ku ɖe "$1" ŋu',
+'whatlinkshere-page'  => 'Axa:',
 'linkshere'           => "Axa siwo le afisia ku ɖe '''[[:$1]]''' ŋu:",
 'nolinkshere'         => "Axa aɖeke meku ɖe '''[[:$1]]''' ŋu o.",
 'whatlinkshere-prev'  => '{{PLURAL:$1|do ŋgɔ|$1 do ŋgɔ}}',
 'whatlinkshere-next'  => '{{PLURAL:$1|eyome|$1 eyome}}',
 
 # Block/unblock
-'blockip'            => 'Xe mɔ na ezãla sia',
-'blockip-legend'     => 'Xe mɔ na ezãla sia',
-'ipboptions'         => 'gaƒoƒo 2:2 hours,ŋkeke 1:1 day,ŋkeke 3:3 days,kɔsiɖa 1:1 week,kɔsiɖa 2:2 weeks,ɣleti 1:1 month,ɣleti 3:3 months,ɣleti 6:6 months,ƒe 1:1 year,tegbe:infinite', # display1:time1,display2:time2,...
-'createaccountblock' => 'woxe mɔ na ŋkɔa ŋɔŋlɔ',
-'blocklink'          => 'xemɔ',
-'unblocklink'        => 'ɖe mɔxexe',
+'blockip'                  => 'Xe mɔ na ezãla sia',
+'blockip-legend'           => 'Xe mɔ na ezãla sia',
+'ipboptions'               => 'gaƒoƒo 2:2 hours,ŋkeke 1:1 day,ŋkeke 3:3 days,kɔsiɖa 1:1 week,kɔsiɖa 2:2 weeks,ɣleti 1:1 month,ɣleti 3:3 months,ɣleti 6:6 months,ƒe 1:1 year,tegbe:infinite', # display1:time1,display2:time2,...
+'createaccountblock'       => 'woxe mɔ na ŋkɔa ŋɔŋlɔ',
+'blocklink'                => 'xemɔ',
+'unblocklink'              => 'ɖe mɔxexe',
+'change-blocklink'         => 'ɖɔli mɔxexe',
+'blocklogentry'            => 'xemɔ na [[$1]] vaseɖe $2 megbe $3',
+'block-log-flags-nocreate' => 'wo xemɔ na ŋkɔ ŋɔŋlɔ',
 
 # Move page
 'move-page-legend' => 'Ɖɔli eƒe nɔƒe',
@@ -350,28 +428,42 @@ Tia ŋkɔ alo tanya bubu.',
 'movedto'          => 'wohee yi',
 '1movedto2'        => '[[$1]] wohee yi [[$2]]',
 
+# Export
+'export' => 'Ɖo axa siawo ɖa',
+
 # Namespace 8 related
 'allmessages' => 'Gbeƒãɖeɖewo',
 
+# Thumbnails
+'thumbnail-more' => 'Ne lolo ɖe edzi',
+
 # Tooltip help for the actions
 'tooltip-pt-preferences'        => 'Nyeƒe didiwo',
 'tooltip-pt-logout'             => 'Do le eme',
 'tooltip-ca-edit'               => 'Wòateŋu aɖɔ axa sia ɖo.
 Ne ewɔvɔ la, tia "Fiae do ŋgɔ" kpea gbã hafi na dzrae ɖo.',
+'tooltip-ca-addsection'         => 'Dze akpa yeye gɔme',
 'tooltip-ca-viewsource'         => 'Wo dokpɔ ɖe axa sia ŋu.
 Wòateŋu akpɔ alesi woŋlɔe.',
+'tooltip-ca-protect'            => 'Dzɔ axa sia ŋu',
 'tooltip-ca-delete'             => 'Tutu axa sia',
 'tooltip-ca-move'               => 'Ɖɔli axa sia ƒe nɔƒe',
 'tooltip-search'                => 'Dii {{SITENAME}}',
+'tooltip-search-go'             => 'Yi axa si ƒe ŋkɔ enye esia ne woŋlɔe xoxo',
+'tooltip-search-fulltext'       => 'Di nyasiawo le axawo me.',
 'tooltip-n-recentchanges'       => 'Tɔtrɔ yeyewo le wiki sia me.',
 'tooltip-n-randompage'          => 'Kpɔ axa ɖesiaɖe ko',
 'tooltip-n-help'                => 'Nuwo srɔ̃ƒe',
 'tooltip-t-whatlinkshere'       => 'Wiki nuŋɔŋlɔwo katã siwo ku ɖe afii ŋuti',
 'tooltip-t-recentchangeslinked' => 'Tɔtrɔ yeyewo le axa siwo ku ɖe axa sia ŋuti',
+'tooltip-t-contributions'       => 'Kpɔ nusiwo amesia ŋlɔ',
 'tooltip-t-upload'              => 'Ɖo nutatawo kple nuƒoƒowo ɖa',
 'tooltip-t-specialpages'        => 'Axa tɔxewo ƒe xexlẽme',
+'tooltip-ca-nstab-special'      => 'Axa sia nye axa tɔxe.  Wò mateŋu atrɔ nu aɖeke le edzi o.',
 'tooltip-minoredit'             => 'Esia nye tɔtrɔ sue aɖe ko',
 'tooltip-save'                  => 'Dzra wòƒe tɔtrɔwo ɖo',
+'tooltip-preview'               => 'Kpɔ wò ɖɔɖɔɖowo do ŋgɔ, mía ve nuwo bena na zãe hafi na dzrae ɖo!',
+'tooltip-diff'                  => 'Fia tɔtrɔ siwo newɔ le nuŋɔŋlɔa me',
 
 # Browsing diffs
 'previousdiff' => '← Tata xoxoa',
@@ -381,7 +473,7 @@ Wòateŋu akpɔ alesi woŋlɔe.',
 'newimages' => 'Nutata yeyewo',
 
 # External editor support
-'edit-externally-help' => 'Kpɔ [http://www.mediawiki.org/wiki/Manual:External_editors gɔmedzedze sewo] na kpekpeɖeŋu bubuwo.',
+'edit-externally-help' => '(Kpɔ [http://www.mediawiki.org/wiki/Manual:External_editors gɔmedzedze sewo] na kpekpeɖeŋu bubuwo.)',
 
 # 'all' in various places, this might be different for inflected languages
 'watchlistall2' => 'katã',
