@@ -1,5 +1,8 @@
 <?php
 /** Jutish (Jysk)
+ *
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
  *
  * @ingroup Language
  * @file
@@ -119,7 +122,7 @@ $messages = array(
 'hidden-category-category' => 'Skjulte klynger', # Name of the category where hidden categories will be listed
 'listingcontinuesabbrev'   => 'førtgøte',
 
-'mainpagetext'      => 'MediaWiki er nu installeret.',
+'mainpagetext'      => "<big>'''MediaWiki er nu installeret.'''</big>",
 'mainpagedocfooter' => "Se vores engelskspråĝede [http://meta.wikimedia.org/wiki/MediaWiki_localisation dokumentåsje tilpasnenge'm åf æ brugergrænseflade] og [http://meta.wikimedia.org/wiki/MediaWiki_User%27s_Guide æ brugervejlednenge] før åplysnenger åpsætnenge'm og anvendelse.",
 
 'about'          => 'Åm',
@@ -522,7 +525,7 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'imagelinks'                => 'Billethenvesnenger',
 'linkstoimage'              => 'De følgende sider henveser til dette billet:',
 'nolinkstoimage'            => 'Der er engen sider der henveser til dette billet.',
-'sharedupload'              => 'Denne gøret er en fælles læĝenge og ken bruges åf andre projekter.',
+'sharedupload'              => 'Denne gøret er en fælles læĝenge og ken bruges åf andre projekter.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
 'noimage'                   => 'Der er engen gøret ve dette nav, du ken $1',
 'noimage-linktext'          => 'læĝge den åp',
 'uploadnewversion-linktext' => 'Læĝ en ny hersenenge åf denne gøret åp',
@@ -608,7 +611,8 @@ hersenenge, (førge) = førskel til den førge hersenenge, l = lile til mendre 
 'categories' => 'Klynger',
 
 # Special:DeletedContributions
-'deletedcontributions' => 'Slettede brugerbidråg',
+'deletedcontributions'       => 'Slettede brugerbidråg',
+'deletedcontributions-title' => 'Slettede brugerbidråg',
 
 # Special:LinkSearch
 'linksearch'       => 'Søĝ i weblinks',
@@ -846,6 +850,7 @@ Kun endholtet åf æ liste (lenjer startende ve *) bliver brugt. Den første hen
 * datetimeoriginal
 * exposuretime
 * fnumber
+* isospeedratings
 * focallength', # Do not translate list items
 
 # External editor support
