@@ -1,5 +1,8 @@
 <?php
 /** Sindhi (سنڌي)
+ *
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
  *
  * @ingroup Language
  * @file
@@ -100,6 +103,59 @@ $specialPageAliases = array(
 	'Invalidateemail'           => array( 'ناقابلڪار برقٽپال' ),
 );
 
+$magicWords = array(
+	'redirect'              => array( '0', '#چوريو', '#REDIRECT' ),
+	'localmonth'            => array( '1', 'مقاميمهينو', 'LOCALMONTH' ),
+	'localmonthname'        => array( '1', 'مقاميمهينونالو', 'LOCALMONTHNAME' ),
+	'localday'              => array( '1', 'مقاميڏينهن', 'LOCALDAY' ),
+	'localday2'             => array( '1', 'مقاميڏينهن2', 'LOCALDAY2' ),
+	'localdayname'          => array( '1', 'مقاميڏينهننالو', 'LOCALDAYNAME' ),
+	'localyear'             => array( '1', 'مقاميسال', 'LOCALYEAR' ),
+	'localtime'             => array( '1', 'مقاميوقت', 'LOCALTIME' ),
+	'localhour'             => array( '1', 'مقاميڪلاڪ', 'LOCALHOUR' ),
+	'numberofpages'         => array( '1', 'صفحنجوتعداد', 'NUMBEROFPAGES' ),
+	'numberofarticles'      => array( '1', 'مضموننجوتعداد', 'NUMBEROFARTICLES' ),
+	'numberoffiles'         => array( '1', 'فائيلنجوتعداد', 'NUMBEROFFILES' ),
+	'numberofusers'         => array( '1', 'يوزرسجوتعداد', 'NUMBEROFUSERS' ),
+	'numberofedits'         => array( '1', 'ترميمنجوتعداد', 'NUMBEROFEDITS' ),
+	'pagename'              => array( '1', 'صفحيجوعنوان', 'PAGENAME' ),
+	'namespace'             => array( '1', 'نانئپولار', 'NAMESPACE' ),
+	'talkspace'             => array( '1', 'بحثپولار', 'TALKSPACE' ),
+	'subjectspace'          => array( '1', 'مضمونپولار', 'SUBJECTSPACE', 'ARTICLESPACE' ),
+	'fullpagename'          => array( '1', 'صحفيجوپورونالو', 'FULLPAGENAME' ),
+	'msg'                   => array( '0', 'نياپو:', 'MSG:' ),
+	'img_right'             => array( '1', 'ساڄو', 'right' ),
+	'img_left'              => array( '1', 'کاٻو', 'left' ),
+	'img_none'              => array( '1', 'ڪجهنه', 'none' ),
+	'img_width'             => array( '1', '$1 عڪسلون', '$1px' ),
+	'img_center'            => array( '1', 'مرڪز', 'center', 'centre' ),
+	'img_top'               => array( '1', 'سِرُ', 'top' ),
+	'img_middle'            => array( '1', 'وچ', 'middle' ),
+	'img_bottom'            => array( '1', 'تَرُ', 'bottom' ),
+	'sitename'              => array( '1', 'سرزميننالو', 'SITENAME' ),
+	'ns'                    => array( '0', 'نپ', 'NS:' ),
+	'localurl'              => array( '0', 'مقامييوآريل', 'LOCALURL:' ),
+	'grammar'               => array( '0', 'وياڪرڻ', 'GRAMMAR:' ),
+	'currentweek'           => array( '1', 'هلندڙهفتو', 'CURRENTWEEK' ),
+	'currentdow'            => array( '1', 'اڄوڪوڏينهن', 'CURRENTDOW' ),
+	'localweek'             => array( '1', 'مقاميهفتو', 'LOCALWEEK' ),
+	'localdow'              => array( '1', 'مقاميڏينهن', 'LOCALDOW' ),
+	'plural'                => array( '0', 'جمع', 'PLURAL:' ),
+	'fullurl'               => array( '0', 'مڪمليوآريل', 'FULLURL:' ),
+	'currenttimestamp'      => array( '1', 'هلندڙوقتمهر', 'CURRENTTIMESTAMP' ),
+	'localtimestamp'        => array( '1', 'مقاميوقتمهر', 'LOCALTIMESTAMP' ),
+	'directionmark'         => array( '1', 'طرفنشان', 'DIRECTIONMARK', 'DIRMARK' ),
+	'language'              => array( '0', '#ٻولي:', '#LANGUAGE:' ),
+	'contentlanguage'       => array( '1', 'موادٻولي', 'CONTENTLANGUAGE', 'CONTENTLANG' ),
+	'pagesinnamespace'      => array( '1', 'نپ۾صفحا', 'PAGESINNAMESPACE:', 'PAGESINNS:' ),
+	'numberofadmins'        => array( '1', 'منتظمينجوتعداد', 'NUMBEROFADMINS' ),
+	'special'               => array( '0', 'خاص', 'special' ),
+	'filepath'              => array( '0', 'فائيلڏس', 'FILEPATH:' ),
+	'hiddencat'             => array( '1', '__ لڪل زمرو __', '__HIDDENCAT__' ),
+	'pagesincategory'       => array( '1', 'زمريجاصفحا', 'PAGESINCATEGORY', 'PAGESINCAT' ),
+	'pagesize'              => array( '1', 'صفحيجيماپ', 'PAGESIZE' ),
+);
+
 $messages = array(
 # User preference toggles
 'tog-showtoolbar'         => 'سنوارپ اوزار دٻي ڏيکاريو (جاوا اسڪرپٽ)',
@@ -533,22 +589,21 @@ $1 {{PLURAL:$1|اکر|اکرن}} کان ننڍي هوڻ گھرجي.',
 'listfiles' => 'فائيل فهرست',
 
 # File description page
-'filehist'                       => 'فائيل جي سوانح',
-'filehist-help'                  => 'ڪنهن به تاريخ/وقت تي ڪلڪ ڪري ڏسندا ته تڏڻي اهو فائيل ڪيئن هو.',
-'filehist-current'               => 'هاڻوڪو',
-'filehist-datetime'              => 'تاريخ/وقت',
-'filehist-user'                  => 'يُوزر',
-'filehist-dimensions'            => 'ماپَ',
-'filehist-filesize'              => 'فائيل سائيز',
-'filehist-comment'               => 'تاثرات',
-'imagelinks'                     => 'ڳنڍڻا',
-'linkstoimage'                   => 'هن فائيل سان {{PLURAL:$1|هيٺيون صفحو ڳنڍيل آهي |$1 هيٺيان صفحا ڳنڍيل آهن}}:',
-'nolinkstoimage'                 => 'هن فائيل سان ڪو به صفحو ڳنڍيل ناهي.',
-'sharedupload'                   => 'هيءَ هڪ شراڪتي چاڙهه آهي، تنهنڪري ان کي ٻيون رٿائون به استعمال ڪري سگھن ٿيون.',
-'shareduploadduplicate-linktext' => 'ڪو ٻيو فائيل',
-'noimage'                        => 'ان نالي سان ڪو به فائيل وجود نٿو رکي، جي چاهيو ته $1.',
-'noimage-linktext'               => 'اهو چاڙهيو',
-'uploadnewversion-linktext'      => 'هن فائيل جو نئون پرت چاڙهيو',
+'filehist'                  => 'فائيل جي سوانح',
+'filehist-help'             => 'ڪنهن به تاريخ/وقت تي ڪلڪ ڪري ڏسندا ته تڏڻي اهو فائيل ڪيئن هو.',
+'filehist-current'          => 'هاڻوڪو',
+'filehist-datetime'         => 'تاريخ/وقت',
+'filehist-user'             => 'يُوزر',
+'filehist-dimensions'       => 'ماپَ',
+'filehist-filesize'         => 'فائيل سائيز',
+'filehist-comment'          => 'تاثرات',
+'imagelinks'                => 'ڳنڍڻا',
+'linkstoimage'              => 'هن فائيل سان {{PLURAL:$1|هيٺيون صفحو ڳنڍيل آهي |$1 هيٺيان صفحا ڳنڍيل آهن}}:',
+'nolinkstoimage'            => 'هن فائيل سان ڪو به صفحو ڳنڍيل ناهي.',
+'sharedupload'              => 'هيءَ هڪ شراڪتي چاڙهه آهي، تنهنڪري ان کي ٻيون رٿائون به استعمال ڪري سگھن ٿيون.', # $1 is the repo name, $2 is shareduploadwiki(-desc)
+'noimage'                   => 'ان نالي سان ڪو به فائيل وجود نٿو رکي، جي چاهيو ته $1.',
+'noimage-linktext'          => 'اهو چاڙهيو',
+'uploadnewversion-linktext' => 'هن فائيل جو نئون پرت چاڙهيو',
 
 # MIME search
 'mimesearch' => 'مائيم ڳولا',
