@@ -1,5 +1,8 @@
 <?php
 /** Wu (吴语)
+ *
+ * See MessagesQqq.php for message documentation incl. usage of parameters
+ * To improve a translation please visit http://translatewiki.net
  *
  * @ingroup Language
  * @file
@@ -212,6 +215,7 @@ $messages = array(
 'restorelink'             => '个被删除个版本',
 'site-rss-feed'           => '$1的RSS订阅',
 'site-atom-feed'          => '$1的Atom订阅',
+'red-link-title'          => '$1 (网页不存在)',
 
 # Short words for each namespace, by default used in the namespace tab in monobook
 'nstab-main'      => '文章',
@@ -359,16 +363,19 @@ $messages = array(
 'diff-multi'              => '($1个中途个修订版本无没显示。)',
 
 # Search results
-'searchresults'         => '搜索结果',
-'searchresulttext'      => '更加全面个关于拉{{SITENAME}}里向搜索个信息，请倷看[[{{MediaWiki:Helppage}}:搜索|搜索{{SITENAME}}]]。',
-'searchsubtitle'        => "倷搜寻 '''[[:$1]]'''",
-'searchsubtitleinvalid' => "倷搜寻 '''$1'''",
-'noexactmatch'          => "''呒拨叫\"\$1\"个页面啘。''' 倷可以[[:\$1|建立俚]]。",
-'prevn'                 => '上个 $1',
-'nextn'                 => '下个 $1',
-'viewprevnext'          => '查看 ($1) ($2) ($3)',
-'searchhelp-url'        => 'Help:目录',
-'powersearch'           => '高级搜索',
+'searchresults'             => '搜索结果',
+'searchresulttext'          => '更加全面个关于拉{{SITENAME}}里向搜索个信息，请倷看[[{{MediaWiki:Helppage}}:搜索|搜索{{SITENAME}}]]。',
+'searchsubtitle'            => "倷搜寻 '''[[:$1]]'''",
+'searchsubtitleinvalid'     => "倷搜寻 '''$1'''",
+'noexactmatch'              => "''呒拨叫\"\$1\"个页面啘。''' 倷可以[[:\$1|建立俚]]。",
+'prevn'                     => '上个 $1',
+'nextn'                     => '下个 $1',
+'viewprevnext'              => '查看 ($1) ($2) ($3)',
+'searchhelp-url'            => 'Help:目录',
+'search-result-size'        => '$1（$2字）',
+'search-mwsuggest-enabled'  => '与建议',
+'search-mwsuggest-disabled' => ' 没有建议',
+'powersearch'               => '高级搜索',
 
 # Preferences page
 'preferences'           => '偏好',
@@ -733,6 +740,7 @@ $messages = array(
 'tooltip-ca-delete'          => '删脱该只页面',
 'tooltip-ca-move'            => '移动该只页面',
 'tooltip-search'             => '搜寻{{SITENAME}}',
+'tooltip-search-go'          => '转到页本确切名称，如果存在',
 'tooltip-p-logo'             => '封面',
 'tooltip-n-mainpage'         => '进入封面',
 'tooltip-n-portal'           => '关于本计划，可以做什么，应该如何做',
@@ -772,6 +780,13 @@ $messages = array(
 'showhidebots' => '（$1机器人）',
 'ilsubmit'     => '搜寻',
 
+# Bad image list
+'bad_image_list' => '格式如下：
+
+只列出项目（线开始* ）的审议。
+第一个环节上线必须是一个链接到一个坏文件。
+其后的任何链接在同一行被认为是例外情况，即网页的文件，则可能会发生内部。',
+
 /*
 Short names for language variants used for language conversion links.
 To disable showing a particular link, set it to 'disable', e.g.
@@ -821,6 +836,9 @@ Variants for Chinese language
 # action=purge
 'confirm_purge_button' => '确定',
 
+# Separators for various lists, etc.
+'comma-separator' => '、',
+
 # Multipage image navigation
 'imgmultipageprev' => '← 上一页',
 'imgmultipagenext' => '下一页 →',
