@@ -1,32 +1,37 @@
 <?php
 /**
- * See skin.txt
+ * See docs/skin.txt
  *
  * @todo document
- * @package MediaWiki
- * @subpackage Skins
+ * @file
+ * @ingroup Skins
  */
 
 if( !defined( 'MEDIAWIKI' ) )
-	die();
+	die( -1 );
 
 /** */
-require_once('MonoBook.php');
+require_once( dirname(__FILE__) . '/MonoBook.php' );
 
 /**
  * @todo document
- * @package MediaWiki
- * @subpackage Skins
+ * @ingroup Skins
  */
 class SkinSimple extends SkinTemplate {
-	function initPage( &$out ) {
+	function initPage( OutputPage $out ) {
 		SkinTemplate::initPage( $out );
 		$this->skinname  = 'simple';
 		$this->stylename = 'simple';
 		$this->template  = 'MonoBookTemplate';
 	}
 
-	function reallyDoGetUserStyles() {
+	function setupSkinUserCss( OutputPage $out ){
+		$out->addStyle( 'simple/main.css', 'screen' );
+		$out->addStyle( 'simple/rtl.css', '', '', 'rtl' );
+
+	}
+
+	function reallyGenerateUserStylesheet() {
 		global $wgUser;
 		$s = '';
 		if (($undopt = $wgUser->getOption("underline")) != 2) {
@@ -67,4 +72,4 @@ END;
 	}
 }
 
-?>
+
